=====================
 sopel-cryptocurrency
=====================

|version| |build| |issues| |alerts| |coverage-status| |license|

Introduction
============
sopel-cryptocurrency is a cryptocurrency lookup module for Sopel.

Usage
=====

Bitcoin
~~~~~~~
.. code-block::

    .btc
    BTC $7646.86 (-0.11%)⬇ (Last Updated: a minute ago)

Dogecoin
~~~~~~~~
.. code-block::

    .doge
    DOGE $0.00236524 (0.14%)⬆ (Last Updated: a minute ago)

Ethereum
~~~~~~~~
.. code-block::

    .eth
    ETH $154.931 (-0.04%)⬇ (Last Updated: seconds ago)

Litecoin
~~~~~~~~
.. code-block::

    .ltc
    LTC $48.1955 (-0.31%)⬇ (Last Updated: seconds ago)

Requirements
============

API Key
~~~~~~~
.. code-block::

    https://pro.coinmarketcap.com

Python Requirements
~~~~~~~~~~~~~~~~~~~
.. code-block::

    arrow
    requests
    sopel

.. |version| image:: https://img.shields.io/pypi/v/sopel-modules.cryptocurrency.svg
   :target: https://pypi.python.org/pypi/sopel-modules.cryptocurrency
.. |build| image:: https://travis-ci.com/RustyBower/sopel-cryptocurrency.svg?branch=master
   :target: https://travis-ci.com/RustyBower/sopel-cryptocurrency
.. |issues| image:: https://img.shields.io/github/issues/RustyBower/sopel-cryptocurrency.svg
   :target: https://travis-ci.com/RustyBower/sopel-cryptocurrency/issues
.. |alerts| image:: https://img.shields.io/lgtm/alerts/g/RustyBower/sopel-cryptocurrency.svg
   :target: https://lgtm.com/projects/g/RustyBower/sopel-cryptocurrency/alerts/
.. |coverage-status| image:: https://coveralls.io/repos/github/RustyBower/sopel-cryptocurrency/badge.svg?branch=master
   :target: https://coveralls.io/github/RustyBower/sopel-cryptocurrency?branch=master
.. |license| image:: https://img.shields.io/pypi/l/sopel-modules.cryptocurrency.svg
   :target: https://github.com/RustyBower/sopel-cryptocurrency/blob/master/LICENSE
